=======
MAGNets
=======


.. image:: https://img.shields.io/pypi/v/magnets.svg
        :target: https://pypi.python.org/pypi/magnets

.. image:: https://travis-ci.com/meghnathomas/MAGNets.svg?branch=master
    :target: https://travis-ci.com/meghnathomas/MAGNets

.. image:: https://readthedocs.org/projects/magnets/badge/?version=latest
        :target: https://magnets.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://pepy.tech/badge/magnets
        :target: https://pepy.tech/project/magnets
        :alt: PyPI - Downloads


A Python package to aggregate and reduce water distribution network models


* Free software: MIT license
* Documentation: https://magnets.readthedocs.io.


Features
--------

MAGNets is a Python package designed to perform the reduction and aggregation of water distribution network models. The software is capable of reducing a network around an optional operating point and allows the user to customize which junctions they would like retained in the reduced model. 

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
